@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 BEGIN {
-    our $VERSION   = '0.14';
+    our $VERSION   = '0.15';
     our @EXPORT    = qw( lazy defer force );
     our @EXPORT_OK = qw( is_deferred );
 }
@@ -100,14 +100,21 @@ BEGIN {
     };
 
     {
-        no strict 'refs';
-        no warnings 'redefine';
+        foreach my $sym (grep { $_ ne 'DESTROY' } keys %UNIVERSAL::) {
+            my $code = q[
+                sub $sym {
+                    if ( defined Scalar::Util::blessed($_[0]) ) {
+                        unshift @_, Scalar::Defer::SUB_FORCE()->(shift(@_));
+                        goto &{$_[0]->can("$sym")};
+                    } else {
+                        return shift->SUPER::$sym(@_);
+                    }
+                }
+            ];
 
-        foreach my $sym (keys %UNIVERSAL::) {
-            *{$sym} = sub {
-                unshift @_, Scalar::Defer::SUB_FORCE()->(shift(@_));
-                goto &{$_[0]->can($sym)};
-            };
+            $code =~ s/\$sym/$sym/ge;
+
+            eval $code;
         }
 
         *DESTROY  = \&Scalar::Defer::DESTROY;
